@@ -27,53 +27,64 @@
 
 catalog_makecluster = function(ctg)
 {
-  xmin    <- ymin <- xmax <- ymax <- 0
+  # Bounding box of the catalog
+  xmin <- ymin <- xmax <- ymax <- 0
+
+  # Put some options in short named variables
   buffer  <- opt_chunk_buffer(ctg)
   by_file <- opt_chunk_is_file(ctg)
   start   <- opt_chunk_alignment(ctg)
   width   <- opt_chunk_size(ctg)
 
-  # Creation of a set rectangle that encompasses the catalog
-  # =======================================================
+  # New feature from v2.2.0 to do not process some tiles
+  processed <- ctg@data$processed
+  if (is.null(processed)) processed <- rep(TRUE, nrow(ctg@data))
+  if (!is.logical(processed)) stop("The attribute 'processed' of the catalog is not logical.", call. = FALSE)
+  files <- ctg@data$filename[processed]
 
+  # Creation of a set of rectangles that encompasses the whole catalog
   if (by_file)
   {
-    xmin = ctg@data$Min.X
-    xmax = ctg@data$Max.X
-    ymin = ctg@data$Min.Y
-    ymax = ctg@data$Max.Y
+    xmin <- ctg@data[["Min.X"]]
+    xmax <- ctg@data[["Max.X"]]
+    ymin <- ctg@data[["Min.Y"]]
+    ymax <- ctg@data[["Max.Y"]]
+
+    xmin <- xmin[processed]
+    xmax <- xmax[processed]
+    ymin <- ymin[processed]
+    ymax <- ymax[processed]
   }
   else
   {
     # Bounding box of the catalog
-    bbox = with(ctg@data, c(min(Min.X), min(Min.Y), max(Max.X), max(Max.Y)))
+    bbox <- with(ctg@data, c(min(Min.X), min(Min.Y), max(Max.X), max(Max.Y)))
 
     # Shift to align the grid
-    shift = numeric(2)
-    shift[1] = (bbox[1] - start[1]) %% width
-    shift[2] = (bbox[2] - start[2]) %% width
+    shift <- numeric(2)
+    shift[1] <- (bbox[1] - start[1]) %% width
+    shift[2] <- (bbox[2] - start[2]) %% width
 
     # Generate coordinates of bottom-left corner
-    xmin = seq(bbox[1] - shift[1], bbox[3], width)
-    ymin = seq(bbox[2] - shift[2], bbox[4], width)
-    grid = expand.grid(xmin = xmin, ymin = ymin)
-    xmin = grid$xmin
-    ymin = grid$ymin
-    xmax = xmin + width
-    ymax = ymin + width
+    xmin <- seq(bbox[1] - shift[1], bbox[3], width)
+    ymin <- seq(bbox[2] - shift[2], bbox[4], width)
+    grid <- expand.grid(xmin = xmin, ymin = ymin)
+    xmin <- grid$xmin
+    ymin <- grid$ymin
+    xmax <- xmin + width
+    ymax <- ymin + width
   }
 
   verbose("Creating a set of clusters for the catalog...")
 
-  xcenter = (xmin + xmax)/2
-  ycenter = (ymin + ymax)/2
-  width   = xmax - xmin
-  height  = ymax - ymin
+  # Generate center and width of each cluster
+  xcenter <- (xmin + xmax)/2
+  ycenter <- (ymin + ymax)/2
+  width   <- xmax - xmin
+  height  <- ymax - ymin
 
   # Creation of a set of clusters from the rectangles
-  # ================================================
-
-  if (by_file & buffer <= 0)
+  if (by_file && buffer <= 0)
   {
     clusters = lapply(1:length(xcenter), function(i)
     {
@@ -89,18 +100,15 @@ catalog_makecluster = function(ctg)
   else
   {
     bboxes = mapply(raster::extent, xcenter - width/2, xcenter + width/2, ycenter - height/2, ycenter + height/2)
-    clusters = suppressWarnings(catalog_index(ctg, bboxes, LIDRRECTANGLE, buffer))
+    clusters = suppressWarnings(catalog_index(ctg, bboxes, LIDRRECTANGLE, buffer, processed))
     clusters = clusters[!sapply(clusters, is.null)]
   }
 
   # Post-process the clusters
-  # =========================
-
-  # Specific case for computation speed
-  # -----------------------------------
 
   if (by_file & buffer == 0)
   {
+    # Specific optimisation to remove the "-inside" filter
     clusters <- lapply(clusters, function(x)
     {
       x@filter <- ctg@input_options$filter
@@ -108,9 +116,7 @@ catalog_makecluster = function(ctg)
     })
   }
 
-  # Record the path to write the raster if requested
-  # ------------------------------------------------
-
+  # Record the path where to write the raster if requested
   if (opt_output_files(ctg) != "")
   {
     clusters <- lapply(seq_along(clusters), function(i)
@@ -125,7 +131,7 @@ catalog_makecluster = function(ctg)
       X$YTOP    <- format(clusters[[i]]@bbox[4], scientific = F)
 
       if (by_file)
-        X$ORIGINALFILENAME <- tools::file_path_sans_ext(basename(ctg@data$filename[i]))
+        X$ORIGINALFILENAME <- tools::file_path_sans_ext(basename(files[i]))
 
       filepath  <- paste0(glue::glue_data(X, opt_output_files(ctg)))
       n         <- length(filepath)
@@ -138,13 +144,21 @@ catalog_makecluster = function(ctg)
     })
   }
 
-  # Plot the catalog and the clusters
-  # =================================
+  # Record the alternative directories for remote computation
+  if (ctg@input_options[["alt_dir"]][1] != "")
+  {
+    clusters <- lapply(seq_along(clusters), function(i)
+    {
+      clusters[[i]]@alt_dir <- ctg@input_options[["alt_dir"]]
+      return(clusters[[i]])
+    })
+  }
 
+  # Plot the catalog and the clusters if progress
   if (opt_progress(ctg))
   {
-    xrange = c(min(xmin), max(xmax))
-    yrange = c(min(ymin), max(ymax))
+    xrange = c(min(xmin, ctg@data[["Min.X"]]), max(xmax, ctg@data[["Max.X"]]))
+    yrange = c(min(ymin, ctg@data[["Min.Y"]]), max(ymax, ctg@data[["Max.Y"]]))
     title  = "Pattern of chunks"
     plot.LAScatalog(ctg, mapview = FALSE, chunk_pattern = FALSE, main = title, xlim = xrange, ylim = yrange)
 
