@@ -89,6 +89,13 @@ opt_chunk_size = function(ctg)
 {
   assert_is_a_number(value)
   assert_all_are_non_negative(value)
+
+  if (value > 0) {
+     if (value < 250) {
+       message("Be careful, a chunk size smaller than 250 is likely to be irrelevant.")
+    }
+  }
+
   ctg@chunk_options$size <- value
   return(ctg)
 }
@@ -202,6 +209,7 @@ opt_output_files = function(ctg)
   if (ext != "")
     warning(glue::glue("{value} contains a file extension. Users don't need to provide a file extension. It will be added automaticaly as a function of the output."))
 
+  value <- gsub("\\{?\\*\\}?", "{ORIGINALFILENAME}", value)
   ctg@output_options$output_files <- value
   return(ctg)
 }
