@@ -77,8 +77,10 @@ is.overlapping = function(catalog)
 {
   spdf          <- as.spatial(catalog)
   contour       <- rgeos::gUnaryUnion(spdf)
-  actual_area   <- round(contour@polygons[[1]]@area, 4)
-  measured_area <- round(area(catalog), 4)
+  actual_area   <- contour@polygons[[1]]@area
+  average_area  <- actual_area / length(spdf)
+  measured_area <- area(catalog)
+  actual_area   <- actual_area + 0.0000001 * average_area # fix #310
   return(actual_area < measured_area)
 }
 
